.. module:: enaml.widgets.ipython_console

=============================
enaml.widgets.ipython_console
=============================

.. rubric:: Classes

.. autosummary::
    :nosignatures:

    IPythonConsole


.. autoclass:: IPythonConsole
